(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'jquery'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('jquery'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.jQuery);
        global.jqueryPromise = mod.exports;
    }
})(this, function (exports, _jquery) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });
    exports.default = Promise;


    function finallyImp(callback) {
        return this.then(callback, callback);
    } /**
       * Miniature ES6 Promise polyfill based on jQuery.Deferred.
       *
       * jQuery 3 is Promises/A+ compliant, so this should be good enough for
       * most situations in which jQuery is being imported anyway.
       */

    function toPromise(deferred, target) {
        var promise = deferred.promise(target);
        promise.finally = finallyImp;
        return promise;
    }

    function Promise(executor) {
        var deferred = (0, _jquery.Deferred)();
        var resolve = deferred.resolve.bind(deferred),
            reject = deferred.reject.bind(deferred);
        executor(resolve, reject);
        return toPromise(deferred);
    }

    Promise.all = function (iterable) {
        return toPromise(_jquery.when.apply(null, iterable));
    };

    Promise.race = function (iterable) {
        var deferred = (0, _jquery.Deferred)();
        function resolved(value) {
            if (deferred.state() === 'pending') deferred.resolve(value);
        }
        function rejected(reason) {
            if (deferred.state() === 'pending') deferred.reject(reason);
        }
        (0, _jquery.each)(iterable, function (key, promise) {
            return promise.then(resolved, rejected);
        });
        return toPromise(deferred);
    };

    Promise.resolve = function (value) {
        return toPromise((0, _jquery.Deferred)().resolve(value));
    };

    Promise.reject = function (reason) {
        return toPromise((0, _jquery.Deferred)().reject(reason));
    };

    var local = global || self || window || Function('return this')();

    if (local && !local.Promise) local.Promise = Promise;
});

//# sourceMappingURL=jquery-promise.js.map